;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'tools '("clearcase"))
(custom-add-loads 'clearcase '("clearcase"))

;;; custom-load.el ends here
