;;; DO NOT MODIFY THIS FILE
(if (featurep 'clearcase-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "clearcase/_pkg.el")

(package-provide 'clearcase :version 1.06 :type 'regular)

;;;***

(provide 'clearcase-autoloads)
